summaryrefslogtreecommitdiffstats
path: root/kpilot/conduits/abbrowserconduit/kabcRecord.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/conduits/abbrowserconduit/kabcRecord.h')
-rw-r--r--kpilot/conduits/abbrowserconduit/kabcRecord.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kpilot/conduits/abbrowserconduit/kabcRecord.h b/kpilot/conduits/abbrowserconduit/kabcRecord.h
index 13a3e269..f27f0b1a 100644
--- a/kpilot/conduits/abbrowserconduit/kabcRecord.h
+++ b/kpilot/conduits/abbrowserconduit/kabcRecord.h
@@ -33,7 +33,7 @@
** Bug reports and questions can be sent to kde-pim@kde.org.
*/
-#include <qvaluevector.h>
+#include <tqvaluevector.h>
#include <kabc/phonenumber.h>
@@ -71,20 +71,20 @@ namespace KABCSync
{
public:
Settings();
- QString dateFormat() const
+ TQString dateFormat() const
{
return fDateFormat;
}
- void setDateFormat(const QString& s)
+ void setDateFormat(const TQString& s)
{
fDateFormat = s;
}
- const QValueVector<int> &customMapping() const
+ const TQValueVector<int> &customMapping() const
{
return fCustomMapping;
}
- void setCustomMapping(const QValueVector<int> &v)
+ void setCustomMapping(const TQValueVector<int> &v)
{
if (v.count()==4)
{
@@ -130,8 +130,8 @@ namespace KABCSync
fFaxTypeOnPC = v;
}
private:
- QString fDateFormat;
- QValueVector<int> fCustomMapping;
+ TQString fDateFormat;
+ TQValueVector<int> fCustomMapping;
int fOtherPhone;
bool fPreferHome;
int fFaxTypeOnPC;
@@ -165,12 +165,12 @@ namespace KABCSync
* @return Category index that best matches.
* @return Pilot::Unfiled if no best match.
*/
- unsigned int bestMatchedCategory(const QStringList &categorynames,
+ unsigned int bestMatchedCategory(const TQStringList &categorynames,
const PilotAddressInfo &info,
unsigned int category);
/** As above, but return the name of the category. */
- inline QString bestMatchedCategoryName(const QStringList &categorynames,
+ inline TQString bestMatchedCategoryName(const TQStringList &categorynames,
const PilotAddressInfo &info,
unsigned int category)
{
@@ -181,14 +181,14 @@ namespace KABCSync
/** Give the addressee @p abEntry the category @p cat (leaving
* existing category assignments intact).
*/
- void setCategory(KABC::Addressee &abEntry, const QString &cat);
+ void setCategory(KABC::Addressee &abEntry, const TQString &cat);
/* These are string identifiers used for custom properties in the addressees,
* used to store KPilot-specific settings.
*/
- const QString appString=CSL1("KPILOT"); ///< Identifier for the application
- const QString flagString=CSL1("Flag"); ///< Flags: synced or not
- const QString idString=CSL1("RecordID"); ///< Record ID on HH for this addressee
+ const TQString appString=CSL1("KPILOT"); ///< Identifier for the application
+ const TQString flagString=CSL1("Flag"); ///< Flags: synced or not
+ const TQString idString=CSL1("RecordID"); ///< Record ID on HH for this addressee
/** Get the string value for HH custom field @p index (0..3) from the addressee
@@ -199,9 +199,9 @@ namespace KABCSync
* string @p dateFormat. If this is empty, use the locale setting.
*
* @return String value for HH custom field @p index
* @return Null QString on error (is also a valid return value)
*/
- QString getFieldForHHCustom(
+ TQString getFieldForHHCustom(
unsigned int index,
const KABC::Addressee &abEntry,
const Settings &settings);
@@ -215,7 +215,7 @@ namespace KABCSync
void setFieldFromHHCustom(
const unsigned int index,
KABC::Addressee &abEntry,
- const QString &value,
+ const TQString &value,
const Settings &settings);
/** The HH has a phone type "other" which may be mapped to any one of
@@ -223,7 +223,7 @@ namespace KABCSync
*
* @note @p mappingForOther should come from AbbrowserSettings::pilotOther()
*/
- QString getFieldForHHOtherPhone(const KABC::Addressee &abEntry, const Settings &s);
+ TQString getFieldForHHOtherPhone(const KABC::Addressee &abEntry, const Settings &s);
/** The HH has a phone type "other" which may be mapped to any one
* of several PC side phone numbers. Store the number @p nr in the
@@ -231,7 +231,7 @@ namespace KABCSync
*
* @note @p mappingForOther should come from AbbrowserSettings::pilotOther()
*/
- void setFieldFromHHOtherPhone(KABC::Addressee &abEntry, const QString &nr, const Settings &s);
+ void setFieldFromHHOtherPhone(KABC::Addressee &abEntry, const TQString &nr, const Settings &s);
/** Returns the address portion of an addressee. Since the HH can only store
* one address, we return the preferred address (if the Addressee @p abEntry
@@ -199,9 +199,9 @@ namespace KABCSync
*
* @return String value for HH custom field @p index
- * @return Null QString on error (is also a valid return value)
+ * @return Null TQString on error (is also a valid return value)
*/